@@ -7,7 +7,7 @@ use Mojo::IOLoop;
 # Minimal ioloop example demonstrating how to cheat at HTTP benchmarks :)
 my %buffer;
 Mojo::IOLoop->server(
-  {port => 3000} => sub {
+  {port => 8080} => sub {
     my ($loop, $stream, $id) = @_;
     $buffer{$id} = '';
     $stream->on(
@@ -25,7 +25,7 @@ Mojo::IOLoop->server(
 
           # Write a minimal HTTP response
           # (the "Hello World!" message has been optimized away!)
-          $stream->write("HTTP/1.1 200 OK\x0d\x0a"
+          $stream->write("HTTP/1.1 200 OK\x0d\x0aContent-Length: 0\x0d\x0a"
               . "Connection: keep-alive\x0d\x0a\x0d\x0a");
         }
       }
@@ -35,8 +35,8 @@ Mojo::IOLoop->server(
 ) or die "Couldn't create listen socket!\n";
 
 print <<'EOF';
-Starting server on port 3000.
-Try something like "ab -c 30 -n 100000 -k http://127.0.0.1:3000/" for testing.
+Starting server on port 8080.
+Try something like "wrk -c 100 -d 10s http://127.0.0.1:8080/" for testing.
 On a MacBook Air this results in about 18k req/s.
 EOF
 
