@@ -11,7 +11,7 @@ has reactor => sub {
 
 sub DESTROY { shift->close }
 
-sub new { shift->SUPER::new(handle => shift, buffer => '') }
+sub new { shift->SUPER::new(handle => shift, buffer => '', timeout => 15) }
 
 sub close {
   my $self = shift;
@@ -46,14 +46,14 @@ sub is_writing {
 sub start {
   my $self = shift;
 
-  my $reactor = $self->reactor;
-  $reactor->io($self->timeout(15)->{handle},
-    sub { pop() ? $self->_write : $self->_read })
-    unless $self->{timer};
-
   # Resume
-  $reactor->watch($self->{handle}, 1, $self->is_writing)
+  my $reactor = $self->reactor;
+  return $reactor->watch($self->{handle}, 1, $self->is_writing)
     if delete $self->{paused};
+
+  weaken $self;
+  my $cb = sub { pop() ? $self->_write : $self->_read };
+  $reactor->io($self->timeout($self->{timeout})->{handle} => $cb);
 }
 
 sub stop {
