@@ -1,7 +1,6 @@
 package Mojo::JSON::Pointer;
 use Mojo::Base -base;
 
-use Mojo::Util qw(decode url_unescape);
 use Scalar::Util 'looks_like_number';
 
 sub contains { shift->_pointer(1, @_) }
@@ -10,9 +9,8 @@ sub get      { shift->_pointer(0, @_) }
 sub _pointer {
   my ($self, $contains, $data, $pointer) = @_;
 
-  $pointer = decode('UTF-8', url_unescape $pointer);
   return $data unless $pointer =~ s!^/!!;
-  for my $p (split '/', $pointer) {
+  for my $p ($pointer eq '' ? ($pointer) : (split '/', $pointer)) {
     $p =~ s/~0/~/g;
     $p =~ s!~1!/!g;
 
@@ -33,6 +31,8 @@ sub _pointer {
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 Mojo::JSON::Pointer - JSON Pointers
@@ -47,7 +47,7 @@ Mojo::JSON::Pointer - JSON Pointers
 
 =head1 DESCRIPTION
 
-L<Mojo::JSON::Pointer> implements JSON Pointers.
+L<Mojo::JSON::Pointer> is a relaxed implementation of RFC 6901.
 
 =head1 METHODS
 
@@ -59,10 +59,12 @@ Check if data structure contains a value that can be identified with the given
 JSON Pointer.
 
   # True
+  $pointer->contains({'♥' => 'mojolicious'}, '/♥');
   $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/foo');
   $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/baz/2');
 
   # False
+  $pointer->contains({'♥' => 'mojolicious'}, '/☃');
   $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/bar');
   $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/baz/9');
 
@@ -72,6 +74,9 @@ JSON Pointer.
 
 Extract value identified by the given JSON Pointer.
 
+  # "mojolicious"
+  $pointer->get({'♥' => 'mojolicious'}, '/♥');
+
   # "bar"
   $pointer->get({foo => 'bar', baz => [4, 5, 6]}, '/foo');
 
