@@ -120,7 +120,7 @@ L<Mojo::Message::Response> object.
 Perform GET request with L<Mojo::UserAgent/"get"> and return resulting
 L<Mojo::Message::Response> object.
 
-  $ perl -Mojo -E 'say g("mojolicio.us")->dom("h1, h2, h3")->pluck("text")'
+  $ perl -Mojo -E 'say g("mojolicio.us")->dom("h1, h2, h3")->text'
 
 =head2 h
 
